Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon QLDB.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, resources, and condition keys for Amazon QLDB - AWS Identity and Access Management

# Actions, resources, and condition keys for Amazon QLDB

Tip

This page is moving to a new location on November 16, 2020. Please update your bookmark to use the new page at https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonqldb.html .

Amazon QLDB (service prefix: `qldb` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon QLDB
- Resource types defined by Amazon QLDB
- Condition keys for Amazon QLDB

## Actions defined by Amazon QLDB

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CancelJournalKinesisStream | Grants permission to cancel a journal kinesis stream | Write | stream* |  |
CreateLedger | Grants permission to create a ledger | Write | ledger* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteLedger | Grants permission to delete a ledger | Write | ledger* |  |
DescribeJournalKinesisStream | Grants permission to describe information about a journal kinesis stream | Read | stream* |  |
DescribeJournalS3Export | Grants permission to describe information about a journal export job | Read | ledger* |  |
DescribeLedger | Grants permission to describe a ledger | Read | ledger* |  |
ExecuteStatement | Grants permission to send commands to a ledger via the console | Write | ledger* |  |
ExportJournalToS3 | Grants permission to export journal contents to an Amazon S3 bucket | Write | ledger* |  |
GetBlock | Grants permission to retrieve a block from a ledger for a given BlockAddress | Read | ledger* |  |
GetDigest | Grants permission to retrieve a digest from a ledger for a given BlockAddress | Read | ledger* |  |
GetRevision | Grants permission to retrieve a revision for a given document ID and a given BlockAddress | Read | ledger* |  |
InsertSampleData | Grants permission to insert sample application data via the console | Write | ledger* |  |
ListJournalKinesisStreamsForLedger | Grants permission to list journal kinesis streams for a specified ledger | List | stream* |  |
ListJournalS3Exports | Grants permission to list journal export jobs for all ledgers | List |  |  |
ListJournalS3ExportsForLedger | Grants permission to list journal export jobs for a specified ledger | List | ledger* |  |
ListLedgers | Grants permission to list existing ledgers | List |  |  |
ListTagsForResource | Grants permission to list tags for a resource | Read | ledger |  |
SendCommand | Grants permission to send commands to a ledger | Write | ledger* |  |
ShowCatalog | Grants permission to view a ledger's catalog via the console | Write | ledger* |  |
StreamJournalToKinesis | Grants permission to stream journal contents to a Kinesis Data Stream | Write | stream* |  |
TagResource | Grants permission to add one or more tags to a resource | Tagging | ledger |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to remove one or more tags to a resource | Tagging | ledger |  |
| aws:TagKeys |
UpdateLedger | Grants permission to update properties on a ledger | Write | ledger* |  |

## Resource types defined by Amazon QLDB

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
ledger | `arn:$ { Partition}:qldb:$ { Region}:$ { Account}:ledger/$ { LedgerName}` | aws:ResourceTag/${TagKey}
stream | `arn:$ { Partition}:qldb:$ { Region}:$ { Account}:stream/$ { LedgerName}/$ { StreamId}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon QLDB

Amazon QLDB defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters actions based on the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters actions based on tag key-value pairs attached to the resource | String
aws:TagKeys | Filters actions based on the presence of tag keys in the request | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.